@@ -45,7 +45,7 @@ from .liquidatablereport import LiquidatableReport
 
 class AccountLiquidator(metaclass=abc.ABCMeta):
     def __init__(self) -> None:
-        self.logger: logging.Logger = logging.getLogger(self.__class__.__name__)
+        self._logger: logging.Logger = logging.getLogger(self.__class__.__name__)
 
     @abc.abstractmethod
     def prepare_instructions(self, liquidatable_report: LiquidatableReport) -> typing.Sequence[TransactionInstruction]:
@@ -56,7 +56,7 @@ class AccountLiquidator(metaclass=abc.ABCMeta):
         raise NotImplementedError("AccountLiquidator.liquidate() is not implemented on the base type.")
 
 
-# # 🌬️ NullAccountLiquidator class
+# # NullAccountLiquidator class
 #
 # A 'null', 'no-op', 'dry run' implementation of the `AccountLiquidator` class.
 #
@@ -69,5 +69,5 @@ class NullAccountLiquidator(AccountLiquidator):
         return []
 
     def liquidate(self, liquidatable_report: LiquidatableReport) -> typing.Optional[typing.Sequence[str]]:
-        self.logger.info(f"Skipping liquidation of account [{liquidatable_report.account.address}]")
+        self._logger.info(f"Skipping liquidation of account [{liquidatable_report.account.address}]")
         return None
