@@ -36,7 +36,7 @@ class MarketMaker:
                  market_instruction_builder: mango.MarketInstructionBuilder,
                  desired_orders_chain: Chain, order_reconciler: OrderReconciler,
                  redeem_threshold: typing.Optional[Decimal]) -> None:
-        self.logger: logging.Logger = logging.getLogger(self.__class__.__name__)
+        self._logger: logging.Logger = logging.getLogger(self.__class__.__name__)
         self.wallet: mango.Wallet = wallet
         self.market: mango.Market = market
         self.market_instruction_builder: mango.MarketInstructionBuilder = market_instruction_builder
@@ -52,7 +52,7 @@ class MarketMaker:
 
     def pulse(self, context: mango.Context, model_state: mango.ModelState) -> None:
         try:
-            self.logger.debug(f"[{context.name}] Pulse started with oracle price:\n    {model_state.price}")
+            self._logger.debug(f"[{context.name}] Pulse started with oracle price:\n    {model_state.price}")
 
             payer = mango.CombinableInstructions.from_wallet(self.wallet)
 
@@ -65,15 +65,26 @@ class MarketMaker:
             # It also gives the opportunity to code outside the orderchain to set `not_quoting` if that
             # code has access to the `model_state`.
             if model_state.not_quoting:
-                self.logger.info(f"[{context.name}] Market-maker not quoting - model_state.not_quoting is set.")
+                self._logger.info(f"[{context.name}] Market-maker not quoting - model_state.not_quoting is set.")
                 return
 
             existing_orders = model_state.current_orders()
+            self._logger.debug(f"""Before reconciliation: all owned orders on current orderbook [{model_state.market.symbol}]:
+    {mango.indent_collection_as_str(existing_orders)}""")
             reconciled = self.order_reconciler.reconcile(model_state, existing_orders, desired_orders)
+            self._logger.debug(f"""After reconciliation
+Keep:
+    {mango.indent_collection_as_str(reconciled.to_keep)}
+Cancel:
+    {mango.indent_collection_as_str(reconciled.to_cancel)}
+Place:
+    {mango.indent_collection_as_str(reconciled.to_place)}
+Ignore:
+    {mango.indent_collection_as_str(reconciled.to_ignore)}""")
 
             cancellations = mango.CombinableInstructions.empty()
             for to_cancel in reconciled.to_cancel:
-                self.logger.info(f"Cancelling {self.market.symbol} {to_cancel}")
+                self._logger.info(f"Cancelling {self.market.symbol} {to_cancel}")
                 cancel = self.market_instruction_builder.build_cancel_order_instructions(to_cancel, ok_if_missing=True)
                 cancellations += cancel
 
@@ -82,7 +93,7 @@ class MarketMaker:
                 desired_client_id: int = context.generate_client_id()
                 to_place_with_client_id = to_place.with_client_id(desired_client_id)
 
-                self.logger.info(f"Placing {self.market.symbol} {to_place_with_client_id}")
+                self._logger.info(f"Placing {self.market.symbol} {to_place_with_client_id}")
                 place_order = self.market_instruction_builder.build_place_order_instructions(to_place_with_client_id)
                 place_orders += place_order
 
@@ -100,14 +111,14 @@ class MarketMaker:
             self.pulse_complete.on_next(datetime.now())
         except (mango.RateLimitException, mango.NodeIsBehindException, mango.BlockhashNotFoundException, mango.FailedToFetchBlockhashException) as common_exception:
             # Don't bother with a long traceback for these common problems.
-            self.logger.error(f"[{context.name}] Market-maker problem on pulse: {common_exception}")
+            self._logger.error(f"[{context.name}] Market-maker problem on pulse: {common_exception}")
             self.pulse_error.on_next(common_exception)
         except Exception as exception:
-            self.logger.error(f"[{context.name}] Market-maker error on pulse:\n{traceback.format_exc()}")
+            self._logger.error(f"[{context.name}] Market-maker error on pulse:\n{traceback.format_exc()}")
             self.pulse_error.on_next(exception)
 
     def __str__(self) -> str:
-        return f"""« 𝙼𝚊𝚛𝚔𝚎𝚝𝙼𝚊𝚔𝚎𝚛 for market '{self.market.symbol}' »"""
+        return f"""« MarketMaker for market '{self.market.symbol}' »"""
 
     def __repr__(self) -> str:
         return f"{self}"
