@@ -38,14 +38,14 @@ from ..calculators.spotcollateralcalculator import SpotCollateralCalculator
 
 class ModelStateBuilder(metaclass=abc.ABCMeta):
     def __init__(self) -> None:
-        self.logger: logging.Logger = logging.getLogger(self.__class__.__name__)
+        self._logger: logging.Logger = logging.getLogger(self.__class__.__name__)
 
     @abc.abstractmethod
     def build(self, context: mango.Context) -> ModelState:
         raise NotImplementedError("ModelStateBuilder.build() is not implemented on the base type.")
 
     def __str__(self) -> str:
-        return "« 𝙼𝚘𝚍𝚎𝚕𝚂𝚝𝚊𝚝𝚎𝙱𝚞𝚒𝚕𝚍𝚎𝚛 »"
+        return "« ModelStateBuilder »"
 
     def __repr__(self) -> str:
         return f"{self}"
@@ -64,7 +64,7 @@ class WebsocketModelStateBuilder(ModelStateBuilder):
         return self.model_state
 
     def __str__(self) -> str:
-        return f"« 𝚆𝚎𝚋𝚜𝚘𝚌𝚔𝚎𝚝𝙼𝚘𝚍𝚎𝚕𝚂𝚝𝚊𝚝𝚎𝙱𝚞𝚒𝚕𝚍𝚎𝚛 for market '{self.model_state.market.symbol}' »"
+        return f"« WebsocketModelStateBuilder for market '{self.model_state.market.symbol}' »"
 
 
 # # 🥭 PollingModelStateBuilder class
@@ -79,7 +79,7 @@ class PollingModelStateBuilder(ModelStateBuilder):
         started_at = time.time()
         built: ModelState = self.poll(context)
         time_taken = time.time() - started_at
-        self.logger.debug(f"Poll for model state complete. Time taken: {time_taken:.2f} seconds.")
+        self._logger.debug(f"Poll for model state complete. Time taken: {time_taken:.2f} seconds.")
         return built
 
     @abc.abstractmethod
@@ -101,7 +101,7 @@ class PollingModelStateBuilder(ModelStateBuilder):
                           placed_orders_container_watcher, inventory_watcher, orderbook_watcher)
 
     def __str__(self) -> str:
-        return "« 𝙿𝚘𝚕𝚕𝚒𝚗𝚐𝙼𝚘𝚍𝚎𝚕𝚂𝚝𝚊𝚝𝚎𝙱𝚞𝚒𝚕𝚍𝚎𝚛 »"
+        return "« PollingModelStateBuilder »"
 
 
 # # 🥭 SerumPollingModelStateBuilder class
@@ -176,7 +176,7 @@ class SerumPollingModelStateBuilder(PollingModelStateBuilder):
         return self.from_values(self.order_owner, self.market, group, account, price, placed_orders_container, inventory, orderbook)
 
     def __str__(self) -> str:
-        return f"""« 𝚂𝚎𝚛𝚞𝚖𝙿𝚘𝚕𝚕𝚒𝚗𝚐𝙼𝚘𝚍𝚎𝚕𝚂𝚝𝚊𝚝𝚎𝙱𝚞𝚒𝚕𝚍𝚎𝚛 for market '{self.market.symbol}' »"""
+        return f"""« SerumPollingModelStateBuilder for market '{self.market.symbol}' »"""
 
 
 # # 🥭 SpotPollingModelStateBuilder class
@@ -261,7 +261,7 @@ class SpotPollingModelStateBuilder(PollingModelStateBuilder):
         return self.from_values(self.order_owner, self.market, group, account, price, placed_orders_container, inventory, orderbook)
 
     def __str__(self) -> str:
-        return f"""« 𝚂𝚙𝚘𝚝𝙿𝚘𝚕𝚕𝚒𝚗𝚐𝙼𝚘𝚍𝚎𝚕𝚂𝚝𝚊𝚝𝚎𝙱𝚞𝚒𝚕𝚍𝚎𝚛 for market '{self.market.symbol}' »"""
+        return f"""« SpotPollingModelStateBuilder for market '{self.market.symbol}' »"""
 
 
 # # 🥭 PerpPollingModelStateBuilder class
@@ -325,4 +325,4 @@ class PerpPollingModelStateBuilder(PollingModelStateBuilder):
         return self.from_values(self.order_owner, self.market, group, account, price, placed_orders_container, inventory, orderbook)
 
     def __str__(self) -> str:
-        return f"""« 𝙿𝚎𝚛𝚙𝙿𝚘𝚕𝚕𝚒𝚗𝚐𝙼𝚘𝚍𝚎𝚕𝚂𝚝𝚊𝚝𝚎𝙱𝚞𝚒𝚕𝚍𝚎𝚛 for market '{self.market.symbol}' »"""
+        return f"""« PerpPollingModelStateBuilder for market '{self.market.symbol}' »"""
